@@ -8,7 +8,6 @@ package Gitolite::Rc;
   glrc
   query_rc
   version
-  greeting
   trigger
   _which
 
@@ -21,6 +20,7 @@ package Gitolite::Rc;
 );
 
 use Exporter 'import';
+use Getopt::Long;
 
 use Gitolite::Common;
 
@@ -62,12 +62,12 @@ $UNSAFE_PATT          = qr([`~#\$\&()|;<>]);
 my $current_data_version = "3.2";
 
 my $rc = glrc('filename');
-if ( -r $rc and -s $rc ) {
+if (-r $rc and -s $rc) {
     do $rc or die $@;
 }
 if ( defined($GL_ADMINDIR) ) {
     say2 "";
-    say2 "FATAL: '$rc' seems to be for older gitolite; please see\nhttp://gitolite.com/gitolite/migr.html";
+    say2 "FATAL: '$rc' seems to be for older gitolite; please see doc/g2migr.mkd\n" . "(online at http://gitolite.com/gitolite/g2migr.html)";
 
     exit 1;
 }
@@ -90,11 +90,9 @@ unshift @{ $rc{ACCESS_1} }, 'Writable::access_1';
 # use an env var that is highly unlikely to appear in real life :)
 do $ENV{G3T_RC} if exists $ENV{G3T_RC} and -r $ENV{G3T_RC};
 
-# setup some perl/rc/env vars, plus umask
+# setup some perl/rc/env vars
 # ----------------------------------------------------------------------
 
-umask ( $rc{UMASK} || 0077 );
-
 unshift @INC, "$rc{LOCAL_CODE}/lib" if $rc{LOCAL_CODE};
 
 $ENV{PATH} = "$ENV{GL_BINDIR}:$ENV{PATH}" unless $ENV{PATH} =~ /^$ENV{GL_BINDIR}:/;
@@ -132,7 +130,7 @@ sub non_core_expand {
     my %enable;
 
     for my $e ( @{ $rc{ENABLE} } ) {
-        my ( $name, $arg ) = split ' ', $e, 2;
+        my ($name, $arg) = split ' ', $e, 2;
         # store args as the hash value for the name
         $enable{$name} = $arg || '';
 
@@ -142,8 +140,8 @@ sub non_core_expand {
     }
 
     # bring in additional non-core specs from the rc file, if given
-    if ( my $nc2 = $rc{NON_CORE} ) {
-        for ( $non_core, $nc2 ) {
+    if (my $nc2 = $rc{NON_CORE}) {
+        for ($non_core, $nc2) {
             # beat 'em into shape :)
             s/#.*//g;
             s/[ \t]+/ /g; s/^ //mg; s/ $//mg;
@@ -152,8 +150,8 @@ sub non_core_expand {
 
         for ( split "\n", $nc2 ) {
             next unless /\S/;
-            my ( $name, $where, $module, $before, $name2 ) = split ' ', $_;
-            if ( not $before ) {
+            my ($name, $where, $module, $before, $name2) = split ' ', $_;
+            if (not $before) {
                 $non_core .= "$name $where $module\n";
                 next;
             }
@@ -165,7 +163,7 @@ sub non_core_expand {
     my @data = split "\n", $non_core || '';
     for (@data) {
         next if /^\s*(#|$)/;
-        my ( $name, $where, $module ) = split ' ', $_;
+        my ($name, $where, $module) = split ' ', $_;
 
         # if it appears here, it's not a command, so delete it.  At the end of
         # this loop, what's left in $rc{COMMANDS} will be those names in the
@@ -185,9 +183,6 @@ sub non_core_expand {
 
         push @{ $rc{$where} }, $module;
     }
-
-    # finally, add in commands that were declared in the non-core list
-    map { /^(\S+)/; $rc{COMMANDS}{$1} = 1 } @{ $rc{COMMAND} };
 }
 
 # exported functions
@@ -215,7 +210,6 @@ sub glrc {
 }
 
 my $all   = 0;
-my $dump  = 0;
 my $nonl  = 0;
 my $quiet = 0;
 
@@ -232,24 +226,17 @@ sub query_rc {
         exit 0;
     }
 
-    if ($dump) {
-        require Data::Dumper;
-        $Data::Dumper::Sortkeys = 1;
-        print Data::Dumper::Dumper \%rc;
-        exit 0;
-    }
-
-    my $cv = \%rc;    # current "value"
+    my $cv = \%rc;  # current "value"
     while (@vars) {
         my $v = shift @vars;
 
         # dig into the rc hash, using each var as a component
-        if ( not ref($cv) ) {
+        if (not ref($cv)) {
             _warn "unused arguments...";
             last;
-        } elsif ( ref($cv) eq 'HASH' ) {
+        } elsif (ref($cv) eq 'HASH') {
             $cv = $cv->{$v} || '';
-        } elsif ( ref($cv) eq 'ARRAY' ) {
+        } elsif (ref($cv) eq 'ARRAY') {
             $cv = $cv->[$v] || '';
         } else {
             _die "dont know what to do with " . ref($cv) . " item in the rc file";
@@ -258,17 +245,17 @@ sub query_rc {
 
     # we've run out of arguments so $cv is what we have.  If we're supposed to
     # be quiet, we don't have to print anything so let's get that done first:
-    exit( $cv ? 0 : 1 ) if $quiet;    # shell truth
+    exit ( $cv ? 0 : 1 ) if $quiet;     # shell truth
 
     # print values (notice we ignore the '-n' option if it's a ref)
-    if ( ref($cv) eq 'HASH' ) {
-        print join( "\n", sort keys %$cv ), "\n" if %$cv;
-    } elsif ( ref($cv) eq 'ARRAY' ) {
-        print join( "\n", @$cv ), "\n" if @$cv;
+    if (ref($cv) eq 'HASH') {
+        print join("\n", sort keys %$cv), "\n" if %$cv;
+    } elsif (ref($cv) eq 'ARRAY') {
+        print join("\n", @$cv), "\n" if @$cv;
     } else {
         print $cv . ( $nonl ? '' : "\n" ) if $cv;
     }
-    exit( $cv ? 0 : 1 );              # shell truth
+    exit ( $cv ? 0 : 1 );   # shell truth
 }
 
 sub version {
@@ -281,26 +268,6 @@ sub version {
     return $version;
 }
 
-sub greeting {
-    my $json = shift;
-
-    chomp( my $hn = `hostname -s 2>/dev/null || hostname` );
-    my $gv = substr( `git --version`, 12 );
-    my $gl_user = $ENV{GL_USER} || '';
-    $gl_user = " $gl_user" if $gl_user;
-
-    if ($json) {
-        $json->{GL_USER}          = $ENV{GL_USER};
-        $json->{USER}             = ( $ENV{USER} || "httpd" ) . "\@$hn";
-        $json->{gitolite_version} = version();
-        chomp( $json->{git_version} = $gv );    # this thing has a newline at the end
-        return;
-    }
-
-    # normal output
-    return "hello$gl_user, this is " . ( $ENV{USER} || "httpd" ) . "\@$hn running gitolite3 " . version() . " on git $gv\n";
-}
-
 sub trigger {
     my $rc_section = shift;
 
@@ -308,7 +275,7 @@ sub trigger {
     # name, so setup env from options
     require Gitolite::Conf::Load;
     Gitolite::Conf::Load->import('env_options');
-    env_options( $_[0] ) if $_[0];
+    env_options($_[0]) if $_[0];
 
     if ( exists $rc{$rc_section} ) {
         if ( ref( $rc{$rc_section} ) ne 'ARRAY' ) {
@@ -320,33 +287,33 @@ sub trigger {
                 if ( my ( $module, $sub ) = ( $pgm =~ /^(.*)::(\w+)$/ ) ) {
 
                     require Gitolite::Triggers;
-                    trace( 2, 'trigger module', $module, $sub, @args, $rc_section, @_ );
+                    trace( 1, 'trigger', $module, $sub, @args, $rc_section, @_ );
                     Gitolite::Triggers::run( $module, $sub, @args, $rc_section, @_ );
 
                 } else {
-                    $pgm = _which( "triggers/$pgm", 'x' );
+                    $pgm = _which("triggers/$pgm", 'x');
 
-                    _warn("skipped trigger '$s' (not found or not executable)"), next if not $pgm;
-                    trace( 2, 'trigger command', $s );
+                    _warn("skipped command '$s'"), next if not $pgm;
+                    trace( 2, "command: $s" );
                     _system( $pgm, @args, $rc_section, @_ );    # they better all return with 0 exit codes!
                 }
             }
         }
         return;
     }
-    trace( 3, "'$rc_section' not found in rc" );
+    trace( 2, "'$rc_section' not found in rc" );
 }
 
 sub _which {
     # looks for a file in LOCAL_CODE or GL_BINDIR.  Returns whichever exists
     # (LOCAL_CODE preferred if defined) or 0 if not found.
     my $file = shift;
-    my $mode = shift;    # could be 'x' or 'r'
+    my $mode = shift;   # could be 'x' or 'r'
 
     my @files = ("$rc{GL_BINDIR}/$file");
     unshift @files, ("$rc{LOCAL_CODE}/$file") if $rc{LOCAL_CODE};
 
-    for my $f (@files) {
+    for my $f ( @files ) {
         return $f if -x $f;
         return $f if -r $f and $mode eq 'r';
     }
@@ -358,11 +325,9 @@ sub _which {
 
 =for args
 Usage:  gitolite query-rc -a
-        gitolite query-rc -d
         gitolite query-rc [-n] [-q] rc-variable
 
     -a          print all variables and values (first level only)
-    -d          dump the entire rc structure
     -n          do not append a newline if variable is scalar
     -q          exit code only (shell truth; 0 is success)
 
@@ -389,30 +354,26 @@ Explore:
     gitolite query-rc -a
     # prints all first level variables and values, one per line.  Any that are
     # listed as HASH or ARRAY can be explored further in subsequent commands.
-    gitolite query-rc -d                # dump the entire rc structure
 =cut
 
 sub args {
     my $help = 0;
 
-    require Getopt::Long;
-    Getopt::Long::GetOptions(
+    GetOptions(
         'all|a'   => \$all,
-        'dump|d'  => \$dump,
         'nonl|n'  => \$nonl,
         'quiet|q' => \$quiet,
         'help|h'  => \$help,
     ) or usage();
 
-    _die("'-a' cannot be combined with other arguments or options; run with '-h' for usage") if $all and ( @ARGV or $dump or $nonl or $quiet );
-    usage() if not $all and not $dump and not @ARGV or $help;
+    usage("'-a' cannot be combined with other arguments or options") if $all and ( @ARGV or $nonl or $quiet );
+    usage() if not $all and not @ARGV or $help;
     return @ARGV;
 }
 
 # ----------------------------------------------------------------------
 
-BEGIN {
-    $non_core = "
+BEGIN { $non_core = "
     # No user-servicable parts inside.  Warranty void if seal broken.  Refer
     # servicing to authorised service center only.
 
@@ -423,8 +384,6 @@ BEGIN {
 
     renice                  PRE_GIT         .
 
-    Kindergarten            INPUT           ::
-
     CpuTime                 INPUT           ::
     CpuTime                 POST_GIT        ::
 
@@ -432,19 +391,12 @@ BEGIN {
 
     Alias                   INPUT           ::
 
-    Motd                    INPUT           ::
-    Motd                    PRE_GIT         ::
-    Motd                    COMMAND         motd
-
     Mirroring               INPUT           ::
     Mirroring               PRE_GIT         ::
     Mirroring               POST_GIT        ::
 
     refex-expr              ACCESS_2        RefexExpr::access_2
 
-    expand-deny-messages    ACCESS_1        .
-    expand-deny-messages    ACCESS_2        .
-
     RepoUmask               PRE_GIT         ::
     RepoUmask               POST_CREATE     ::
 
@@ -464,8 +416,6 @@ BEGIN {
     git-config              POST_COMPILE    post-compile/update-git-configs
     git-config              POST_CREATE     post-compile/update-git-configs
 
-    create-with-reference   POST_CREATE     post-compile/create-with-reference
-
     gitweb                  POST_CREATE     post-compile/update-gitweb-access-list
     gitweb                  POST_COMPILE    post-compile/update-gitweb-access-list
 
@@ -473,9 +423,6 @@ BEGIN {
 
     daemon                  POST_CREATE     post-compile/update-git-daemon-access-list
     daemon                  POST_COMPILE    post-compile/update-git-daemon-access-list
-
-    repo-specific-hooks     POST_COMPILE    .
-    repo-specific-hooks     POST_CREATE     .
 ";
 }
 
@@ -511,17 +458,6 @@ __DATA__
 
     # comment out if you don't need all the extra detail in the logfile
     LOG_EXTRA                       =>  1,
-    # logging options
-    # 1. leave this section as is for 'normal' gitolite logging (default)
-    # 2. uncomment this line to log ONLY to syslog:
-    # LOG_DEST                      => 'syslog',
-    # 3. uncomment this line to log to syslog and the normal gitolite log:
-    # LOG_DEST                      => 'syslog,normal',
-    # 4. prefixing "repo-log," to any of the above will **also** log just the
-    #    update records to "gl-log" in the bare repo directory:
-    # LOG_DEST                      => 'repo-log,normal',
-    # LOG_DEST                      => 'repo-log,syslog',
-    # LOG_DEST                      => 'repo-log,syslog,normal',
 
     # roles.  add more roles (like MANAGER, TESTER, ...) here.
     #   WARNING: if you make changes to this hash, you MUST run 'gitolite
@@ -531,9 +467,6 @@ __DATA__
         WRITERS                     =>  1,
     },
 
-    # enable caching (currently only Redis).  PLEASE RTFM BEFORE USING!!!
-    # CACHE                         =>  'Redis',
-
     # ------------------------------------------------------------------
 
     # rc variables used by various features
@@ -541,6 +474,9 @@ __DATA__
     # the 'info' command prints this as additional info, if it is set
         # SITE_INFO                 =>  'Please see http://blahblah/gitolite for more help',
 
+    # the 'desc' command uses this
+        # WRITER_CAN_UPDATE_DESC    =>  1,
+
     # the CpuTime feature uses these
         # display user, system, and elapsed times to user after each git operation
         # DISPLAY_CPU_TIME          =>  1,
@@ -550,20 +486,8 @@ __DATA__
     # the Mirroring feature needs this
         # HOSTNAME                  =>  "foo",
 
-    # TTL for redis cache; PLEASE SEE DOCUMENTATION BEFORE UNCOMMENTING!
-        # CACHE_TTL                 =>  600,
-
-    # ------------------------------------------------------------------
-
-    # suggested locations for site-local gitolite code (see cust.html)
-
-        # this one is managed directly on the server
-        # LOCAL_CODE                =>  "$ENV{HOME}/local",
-
-        # or you can use this, which lets you put everything in a subdirectory
-        # called "local" in your gitolite-admin repo.  For a SECURITY WARNING
-        # on this, see http://gitolite.com/gitolite/non-core.html#pushcode
-        # LOCAL_CODE                =>  "$rc{GL_ADMIN_BASE}/local",
+    # if you enabled 'Shell', you need this
+        # SHELL_USERS_LIST          =>  "$ENV{HOME}/.gitolite.shell-users",
 
     # ------------------------------------------------------------------
 
@@ -584,7 +508,6 @@ __DATA__
             # 'create',
             # 'fork',
             # 'mirror',
-            # 'readme',
             # 'sskm',
             # 'D',
 
@@ -615,20 +538,12 @@ __DATA__
             # access a repo by another (possibly legacy) name
             # 'Alias',
 
-            # give some users direct shell access.  See documentation in
-            # sts.html for details on the following two choices.
-            # "Shell $ENV{HOME}/.gitolite.shell-users",
-            # 'Shell alice bob',
+            # give some users direct shell access
+            # 'Shell',
 
             # set default roles from lines like 'option default.roles-1 = ...', etc.
             # 'set-default-roles',
 
-            # show more detailed messages on deny
-            # 'expand-deny-messages',
-
-            # show a message of the day
-            # 'Motd',
-
         # system admin stuff
 
             # enable mirroring (don't forget to set the HOSTNAME too!)
@@ -646,9 +561,6 @@ __DATA__
             # updates 'description' file instead of 'gitweb.description' config item
             # 'cgit',
 
-            # allow repo-specific hooks to be added
-            # 'repo-specific-hooks',
-
         # performance, logging, monitoring...
 
             # be nice
@@ -668,10 +580,6 @@ __DATA__
             # allow simple line-oriented macros
             # 'macros',
 
-        # Kindergarten mode
-
-            # disallow various things that sensible people shouldn't be doing anyway
-            # 'Kindergarten',
     ],
 
 );
